@@ -53,8 +53,12 @@ class MultipleRequestHandler(tornado.web.RequestHandler):
             for key in keys:
                 try:
                     result.append(app.db.Get(key))
+                    app.get += 1
+                    print key
                 except KeyError:
                     result.append(None)
+                    app.miss += 1
+                    print "miss", key
 
             self.finish(ujson.dumps(result))
         except ValueError:
@@ -66,6 +70,8 @@ class MultipleRequestHandler(tornado.web.RequestHandler):
             mapping = ujson.loads(self.request.body)
             for key, value in mapping.iteritems():
                 app.db.Put(key, value)
+                app.put += 1
+                print "put", key
 
         except (ValueError, AttributeError):
             raise tornado.web.HTTPError(400)
